@@ -1,2 +1,2 @@
 from .robotlibcore import DynamicCore, keyword
-from hook import hook_zh
\ No newline at end of file
+from .hook import hook_zh
\ No newline at end of file
