@@ -5,11 +5,15 @@ from argparse import Namespace
 from locust import HttpLocust, TaskSet, task, runners, InterruptTaskSet
 from locust.util.time import parse_timespan
 from robot.api import logger
+import os, sys, json, time
 import gevent
 import inspect
 
 Locust_Task_Pool = []
 Locust_User_Pool = []
+Locust_Statistics = []
+
+current_milli_time = lambda: int(round(time.time() * 1000))
 
 class LocustKeyword(object):
 
@@ -176,10 +180,12 @@ class LocustKeyword(object):
         ``runtime`` 运行时间，如果超出这个时间执行将被结束
         '''
         num_requests = int(num_clients) * int(hatch_rate)
-        LocustWorker.run(task=task, host=host, num_requests=num_requests, num_clients=num_clients, hatch_rate=hatch_rate, timeout=timeout)
+        return LocustWorker().run(task=task, host=host, num_requests=num_requests, num_clients=num_clients, hatch_rate=hatch_rate, timeout=timeout)
 
 
 class LocustWorker(object):
+    start_time = None
+    end_time = None
     '''
     创建`locust`HTTP任务的核心方法
     `method` 请求方法
@@ -212,6 +218,74 @@ class LocustWorker(object):
         Locust_Task_Pool.append(locust_excutor)
         return locust_excutor
 
+    def stats(self):
+        '''
+        Returns the statistics from the load test in JSON
+        '''
+        statistics = {
+            'requests': [],
+            'num_requests_success': runners.locust_runner.stats.num_requests,
+            'num_requests_fail': runners.locust_runner.stats.num_failures,
+            'locust_host': runners.locust_runner.host,
+            'start_time': self.start_time,
+            'end_time': self.end_time
+        }
+        def parser_path_query(name):
+            '''
+            Extra path and query from url
+            '''
+            path_and_query = name[0].split('?')
+            if len(path_and_query) > 1:
+                return (path_and_query[0], path_and_query[1])
+            else:
+                return (path_and_query[0], None)
+
+        for name, value in runners.locust_runner.stats.entries.items():
+            current_requests = statistics['requests']
+            (path, query) = parser_path_query(name[0])
+            target = {
+                'api': path,
+                'request_type': name[1],
+                'success': {
+                    'num_requests': value.num_requests,
+                    'min_response_time': value.min_response_time,
+                    'median_response_time': value.median_response_time,
+                    'avg_response_time': value.avg_response_time,
+                    'max_response_time': value.max_response_time,
+                    'response_times': value.response_times,
+                    'response_time_percentiles': {
+                        55: value.get_response_time_percentile(0.55),
+                        65: value.get_response_time_percentile(0.65),
+                        75: value.get_response_time_percentile(0.75),
+                        85: value.get_response_time_percentile(0.85),
+                        95: value.get_response_time_percentile(0.95)
+                    },
+                    'total_rps': value.total_rps,
+                    'total_rpm': value.total_rps * 60
+                },
+                'failure': None
+            }
+            if query:
+                target['query'] = query
+            current_requests.append(target)
+            statistics['requests'] = current_requests
+
+        for id, error in runners.locust_runner.errors.items():
+            current_requests = statistics['requests']
+            error_dict = error.to_dict()
+            (path, query) = parser_path_query(name[0])
+            target = {
+                'api': path,
+                'query': query,
+                'request_type': name[1],
+                'success': None,
+                'failure': error_dict
+            }
+            current_requests.append(target)
+            statistics['requests'] = current_requests
+        Locust_Statistics.append(statistics)
+        return statistics
+
     '''
     开始运行压测任务
     `host` 域名
@@ -219,8 +293,7 @@ class LocustWorker(object):
     `num_clients` 模拟用户数
     `hatch_rate` 请求频率
     '''
-    @staticmethod
-    def run(task, host, num_requests=10, num_clients=1, hatch_rate=10, timeout='3m'):
+    def run(self, task, host, num_requests=10, num_clients=1, hatch_rate=10, timeout='3m'):
         logger.info(f'num_requests: {num_requests} num_clients: {num_clients} hatch_rate: {hatch_rate}')
         if task is None:
             all_task = Locust_Task_Pool
@@ -243,8 +316,12 @@ class LocustWorker(object):
         gevent.spawn_later(options.run_time, timelimit_stop)
         runners.locust_runner = runners.LocalLocustRunner(all_task, options)
         runners.locust_runner.start_hatching(wait=True)
+        self.start_time = current_milli_time()
         runners.locust_runner.greenlet.join()
+        self.end_time = current_milli_time()
         globalVaildator.host = host
+        json_result = self.stats()
+        append_to_result()
         for name, value in runners.locust_runner.stats.entries.items():
             max_response_time = "N/A"
             min_response_time = "N/A"
@@ -262,23 +339,43 @@ class LocustWorker(object):
             globalVaildator.vaildate(name[0], value)
         for error in runners.locust_runner.errors.values():
             raise AssertionError(error.error)
-        Locust_Task_Pool.clear()
-        Locust_User_Pool.clear()
+        reset_name_pool()
+        return json_result
 
-'''
-从`task`命名池中获取一个`task name`
-'''
 def fetch_task_name():
+    '''
+    从`task`命名池中获取一个`task name`
+    '''
     return '__rf_locust_task' + str(len(Locust_Task_Pool))
 
-'''
-从`user`命名池获取一个`user name`
-'''
 def fetch_user_name():
+    '''
+    从`user`命名池获取一个`user name`
+    '''
     name = '__rf_locust_user' + str(len(Locust_User_Pool))
     Locust_User_Pool.append(name)
     return name
 
+def reset_name_pool():
+    '''
+    清空命名池
+    '''
+    Locust_Task_Pool.clear()
+    Locust_User_Pool.clear()
+
+def append_to_result():
+    '''
+    将一个json对象写入到文本中
+    '''
+    root = f'{os.getcwd()}/result'
+    if not os.path.exists(root):
+        os.mkdir(root)
+    with open(f'{root}/load-test.json', 'w+') as f:
+        result = {
+            'executions': Locust_Statistics
+        }
+        f.write(json.dumps(result))
+
 class LocustVaildator(object):
     # 最快响应阈值，毫秒级别
     rd_min_threshold = {}
@@ -298,7 +395,6 @@ class LocustVaildator(object):
     def host(self, value):
         self.vaildateHost(value)
         self._host = value
-        pass
 
     def vaildateHost(self, host):
         if not host:
@@ -347,7 +443,6 @@ class RobotBaseTask(TaskSet):
                     BuiltIn().run_keyword(asset, response)
         except Exception as e:
             response.failure(e)
-            self.interrupt()
             return
         response.success()
             
